@@ -11,6 +11,8 @@ def run_workflow(config):
     configs = fit_utils.make_configs(config)
 
     cores = config["cores"]
+    if cores > len(configs):
+        cores = len(configs)
 
     logger.info(f"Running metaDMG on {len(configs)} files in total.")
 
